@@ -25,6 +25,9 @@ def print_error(error):
         display(html_print(cstr("✗ {}".format(error), color="red")))
 
 
+MAX_ROWS = 20
+MAX_COLS = 20
+
 class WallType(IntFlag):
     NORMAL = 1
     REMOVABLE = 2
@@ -88,8 +91,8 @@ class Cell:
         if isinstance(val, WallType):
             val = val.value
         
-        if WallType(val) in WallType.GOAL:
-            self.world._add_goal("wall",  {"x":x, "y": y, "walls": [ui_dir]} )
+        # if WallType(val) in WallType.GOAL:
+        #     self.world._add_goal("wall",  {"x":x, "y": y, "walls": [ui_dir]} )
 
         if direction == Direction.EAST or direction == Direction.WEST:
             self.world.vwalls[x][y] = val
@@ -181,6 +184,7 @@ class WorldModel():
         self.options = {'MAX_INSTRUCTION_COUNT': 1000}
         self.instruction_count = 0
         self.options.update(options)
+        self.js_call_counter = 0
 
         if path is not None:
             data = self.load_json(path)
@@ -217,8 +221,8 @@ class WorldModel():
             call_js_fn(method_name, params)
     
     def set_dimensions(self, rows = 10, cols = 10):
-        self.rows = rows
-        self.cols = cols
+        self.rows = min(rows, MAX_ROWS)
+        self.cols = min(cols, MAX_COLS)
         self.hwalls = [x[:] for x in [[0] * (self.rows + 1)] * (self.cols + 1)]
         self.vwalls = [x[:] for x in [[0] * (self.rows + 1)] * (self.cols + 1)]
         self.tiles = [x[:] for x in [[None] * (self.rows)] * (self.cols)]
